==> piwigo-2.1.6.zip: piwigo/tools/language/translation_validated.inc.php <==
<?php
$validated_keys = array(
  'ar_SA' => array(
	'IP: %s',
	'IP',
	'the wiki',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	),
	
  'cs_CZ' => array(
	'',
	),
	
  'da_DK' => array(
 	'%d Kb',
	'%d hit',
	'%d hits',
	'Connection settings',
	'Login',
	'Display',
	'Filter',
	'Links',
	'N/A',
	'Password',
	'Quick connect',
	'RSS feed',
	'Reset',
	'Tag',
	'Tags',
	'Webmaster',
	'Administration',
	'caddie',
	'download',
	'Logout',
	'Powered by',
	'Auto login',
	'slideshow',
	'SQL queries in',
	'Thumbnails',
	'Menu',
	'IP: %s',
	'Browser: %s',
	'Email: %s',
	'Admin: %s',
	'Rank',
	'cloud',
	'Pause of slideshow',
	'Database type',
	'Installation',
	'Webmaster login',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	'Webmaster password',
	'%d tag',
	'%d tags',
	'Caddie',
	'Database',
	'Elements',
	'Form',
	'Gallery URL',
	'Path',
	'Permalink',
	'Permalinks',
	'Plugins',
	'Position',
	'Rating',
	'Representant',
	'Site manager',
	'Status',
	'Version',
	'Main',
	'File',
	'High definition',
	'email',
	'Send',
	'Remote',
	'Piwigo administration',
	'GD version',
	'[Simulation]',
	'Upload',
	'user_status_admin',
	'user_status_webmaster',
	'IP',
	'Element',
	'Element type',
	'Hoverbox display',
	'Level 8',
	'Plugins up to date',
	'Support',
	'Piwigo Administration',
	'Piwigo version',
	'Original templates',
	'Downloads',
	'Download',
	'Hit',
	'Resize',
	'Miscellaneous',
	'Virtual Links',
	),	

  'de_DE' => array(
 	'%d Kb',
	'Filter',
	'Links',
	'Tag',
	'Tags',
	'Webmaster',
	'Administration',
	'Thumbnails',
	'IP: %s',
	'Browser: %s',
	'Name',
	'Permalink',
	'Permalinks',
	'Plugins',
	'Position',
	'Status',
	'Version',
	'',
	'High definition',
	'Parameter',
	'private',
	'Thumbnail',
	'Simulation',
	'Upload',
	'user_status_admin',
	'user_status_webmaster',
	'IP',
	'Privacy level',
	'Demo',
	'Support',
	'Bugs',
	'Downloads',
	'Installation',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	'Upgrade',
	'Download,',
	'Piwigo Uploader',
	'[Simulation]',
	),

  'es_AR' => array(
	'%d Kb',
	'Webmaster',
	'IP: %s',
	'No',
	),

  'es_ES' => array(
    'Tag',
    'Tags',
	'IP: %s',
	'Email: %s',
	'No',
	'%d tag',
	'%d tags',
	'Plugins',
	'is_high_disabled',
	'nbm_content_goto_2',
	'nbm_content_hello_2',
	'site_local',
	'update_simulation_title',
	'IP',
	'Level 8',
	'DEMO',
	'BUGS',
	'step1_host_info',
	'',
	'General',
	'Local',
	'Demo',
	'Bugs',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	'Piwigo Uploader',
	),
	
  'fr_FR' => array(
    'Dimensions',
    'Identification',
    'Notification',
    'Tag',
    'Tags',
    'admin',
    'identification',
    'redirect_msg',
    'search_date_from',
    'title_menu',
    'IP: %s',
    'Email: %s',
    '%d element',
    '%d elements',
    '%d association',
    '%d associations',
    '%d tag',
    '%d tags',
    'Actions',
    'Description',
    'Informations',
    'Maintenance',
    'Options',
    'Plugins',
    'Position',
    'Validation',
    'Version',
    'config',
    'Date',
    'instructions',
    'is_high_disabled',
    'nbm_content_goto_2',
    'nbm_content_hello_2',
    'nbm_item_notification',
    'nbm_send_options',
    'permissions',
    'public',
    'site_local',
    'update_simulation_title',
    'IP',
    'image',
    'section',
    'tags',
    'high',
    'c13y_Correction',
    'Level 1',
    'Level 8',
    'FORUM',
    'EXTENSIONS',
    'WIKI / DOC',
    'Installation',
    'step1_host_info',
	'Administration',
	'Redirection...',
	'Menu',
	'%d image',
	'%d images',
	'Configuration',
	'Instructions',
	'',
	'Permissions',
	'Local',
	'[Simulation]',
	'Section',
	'Correction',
	'Support',
	'Extensions',
	'Documentation',
	'Photos',
	'pixels',
	'Piwigo Uploader',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	'email',
    ),

  'hr_HR' => array(
	'%d Kb',
	'Filter',
	'Tag',
	'Webmaster',
	'IP: %s',
	'%d tag',
	'user_status_webmaster',
	'IP',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	),
	
  'hu_HU' => array(
	'',
	),

  'it_IT' => array(
	'N/A',
	'No',
	'Webmaster',
	'Password',
	'Home',
	'Menu',
	'Logout',
	'Host',
	'IP',
	'IP: %s',
	'Email',
	'Email: %s',
	'Links',
	'Permalink',
	'Permalinks',
	'Plugins',
	'Plugin',
	'Tools',
	'Tag',
	'Tags',
	'%d tag',
	'%d tags',
	'Directory',
	'File',
	'high',
	'pixels',
	'Downloads',
	'Download',
	'Piwigo Uploader',
	'email',
	'user_status_webmaster',
	),
	
  'ja_JP' => array(
 	'About',
	'Since',
	'Powered by',
 	'IP: %s',
	'IP',
	'Sent by',
	'%d Kb',
	),

  'lv_LV' => array(
 	'%d Kb',
	'N/A',
	'Menu',
 	'IP: %s',
	'IP',
	),
	
  'nl_NL' => array(
 	'%d Kb',
	'Filter',
	'Help',
	'Links',
	'RSS feed',
	'Reset',
	'Tag',
	'Tags',
	'Week %d',
	'download',
	'Powered by',
	'Auto login',
	'Contact',
	'SQL queries in',
	'Menu',
	'IP: %s',
	'Browser: %s',
	'Email: %s',
	'Piwigo Help',
	'%d tag',
	'%d tags',
	'Batch management',
	'Database',
	'Permalink',
	'Permalinks',
	'Plugins',
	'Representant',
	'Site manager',
	'Status',
	'',
	'email',
	'Parameter',
	'Parameters',
	'Remote site',
	'test',
	'Remote',
	'unit mode',
	'Upload',
	'IP',
	'Level 8',
	'Demo',
	'Hits',
	'Downloads',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	'Upgrade',
	'SQL queries',
 	'letters',
	'This author removed the comment with id %d',
	'Database type',
	'Sorry!',
	'Hope to see you back soon.',
	'Hit',
	'pixels',
	'Download',
	'Piwigo Uploader',
	'Download,',
	),

  'no_NO' => array(
 	'IP: %s',
	'Browser: %s',
	'Email: %s',
	'Admin: %s',
	'Pause of slideshow',
	'Album',
	'Filter',
	'N/A',
	'Webmaster',
	'%d Kb',
	'representative',
	'slideshow',
	'Album: %s',
	'Album results for',
	),
	
  'pl_PL' => array(
 	'%d Kb',
	'RSS feed',
	'Webmaster',
	'IP: %s',
	'Tag',
	'Powered by',
	'Email: %s',
	'Admin: %s',
	'%d tag',
	'Status',
	'test',
	'status',
	'user_status_admin',
	'user_status_webmaster',
	'localhost, sql.multimania.com, toto.freesurf.fr',	
	'IP',		
	'Menu',			
	'',
	),

  'pt_BR' => array(
	'',
	),
	
  'pt_PT' => array(
	'',
	),
	
  'ro_RO' => array(
	'%d Kb',
	'N/A',
	'RSS feed',
	'Webmaster',
	'Calendar',
	'Contact',
	),

  'ru_RU' => array(
	'IP',
	'IP: %s',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	'',
	),
	
  'sk_SK' => array(
	'%d Kb',
	'Filter',
	'IP: %s',
	'IP',
	),
  'sh_RS' => array(
 	'%d Kb',
	'Filter',
	'Webmaster',
	'IP: %s',
	'user_status_admin',
	'user_status_webmaster',
	'IP',
	'Element',
	'Host',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	),
	
  'sv_SE' => array(
 	'%d association',
	'Plugins',
	'Position',
	'Representant',
	'Status',
	'Version',
	'High definition',
	'test',
	'status',
	'Piwigo administration',
	'GD version',
	'user_status_webmaster',
	'IP',
	'Element',
	'Piwigo Administration',
	'Piwigo version',
	),
	
  'tr_TR' => array(
 	'%d hit',
	'N/A',
	'Webmaster',
	'IP: %s',
	'Permalink',
	'IP',
	'',
	'',
	'',
	),
	
  'vi_VN' => array(
	'%d Kb',
	'Caddie',
	'Form',
	'Plugins',
	'user_status_webmaster',
	'Templates',
	'pixels',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	'',
	),
	
  'zh_CN' => array(
	'IP',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	),
	
  );
?>

==> piwigo-2.2.4.zip: piwigo/tools/language/translation_validated.inc.php <==
<?php
$validated_keys = array(
  'ar_SA' => array(
	'IP: %s',
	'IP',
	'the wiki',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	),

  'bg_BG' => array(
	'N/A',
	'IP: %s',
	),
	
  'cs_CZ' => array(
	'Album',
	'IP: %s',
	'Album: %s',
	'IP',
	),
	
  'da_DK' => array(
 	'%d Kb',
	'%d hit',
	'%d hits',
	'Connection settings',
	'Login',
	'Display',
	'Filter',
	'Links',
	'N/A',
	'Password',
	'Quick connect',
	'RSS feed',
	'Reset',
	'Tag',
	'Tags',
	'Webmaster',
	'Administration',
	'caddie',
	'download',
	'Logout',
	'Powered by',
	'Auto login',
	'slideshow',
	'SQL queries in',
	'Thumbnails',
	'Menu',
	'IP: %s',
	'Browser: %s',
	'Email: %s',
	'Admin: %s',
	'Rank',
	'cloud',
	'Pause of slideshow',
	'Database type',
	'Installation',
	'Webmaster login',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	'Webmaster password',
	'%d tag',
	'%d tags',
	'Caddie',
	'Database',
	'Elements',
	'Form',
	'Gallery URL',
	'Path',
	'Permalink',
	'Permalinks',
	'Plugins',
	'Position',
	'Rating',
	'Representant',
	'Site manager',
	'Status',
	'Version',
	'Main',
	'File',
	'High definition',
	'email',
	'Send',
	'Remote',
	'Piwigo administration',
	'GD version',
	'[Simulation]',
	'Upload',
	'user_status_admin',
	'user_status_webmaster',
	'IP',
	'Element',
	'Element type',
	'Hoverbox display',
	'Level 8',
	'Plugins up to date',
	'Support',
	'Piwigo Administration',
	'Piwigo version',
	'Original templates',
	'Downloads',
	'Download',
	'Hit',
	'Resize',
	'Miscellaneous',
	'Virtual Links',
	),	

  'de_DE' => array(
 	'%d Kb',
	'Filter',
	'Links',
	'Tag',
	'Tags',
	'Webmaster',
	'Administration',
	'Thumbnails',
	'IP: %s',
	'Browser: %s',
	'Name',
	'Permalink',
	'Permalinks',
	'Plugins',
	'Position',
	'Status',
	'Version',
	'High definition',
	'Parameter',
	'private',
	'Thumbnail',
	'Simulation',
	'Upload',
	'user_status_admin',
	'user_status_webmaster',
	'IP',
	'Privacy level',
	'Demo',
	'Support',
	'Bugs',
	'Downloads',
	'Installation',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	'Upgrade',
	'Download,',
	'Piwigo Uploader',
	'[Simulation]',
	'Album',
	'Album: %s',
	'Remote',
	),

  'el_GR' => array(
	'%d Kb',
	'IP: %s',
	'Email: %s',
	'RSS feed',
	),
	
  'es_AR' => array(
	'%d Kb',
	'Webmaster',
	'IP: %s',
	'No',
	),

  'es_ES' => array(
    'Tag',
    'Tags',
	'IP: %s',
	'Email: %s',
	'No',
	'%d tag',
	'%d tags',
	'Plugins',
	'is_high_disabled',
	'nbm_content_goto_2',
	'nbm_content_hello_2',
	'site_local',
	'update_simulation_title',
	'IP',
	'Level 8',
	'DEMO',
	'BUGS',
	'step1_host_info',
	'Albums',
	'General',
	'Local',
	'Demo',
	'Bugs',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	'Piwigo Uploader',
	),
	
  'fr_FR' => array(
    'Dimensions',
    'Identification',
    'Notification',
    'Tag',
    'Tags',
    'admin',
    'identification',
    'redirect_msg',
    'search_date_from',
    'title_menu',
    'IP: %s',
    'Email: %s',
    '%d element',
    '%d elements',
    '%d association',
    '%d associations',
    '%d tag',
    '%d tags',
    'Actions',
    'Description',
    'Informations',
    'Maintenance',
    'Options',
    'Plugins',
    'Position',
    'Validation',
    'Version',
    'config',
    'Date',
    'instructions',
    'is_high_disabled',
    'nbm_content_goto_2',
    'nbm_content_hello_2',
    'nbm_item_notification',
    'nbm_send_options',
    'permissions',
    'public',
    'site_local',
    'update_simulation_title',
    'IP',
    'image',
    'section',
    'tags',
    'high',
    'c13y_Correction',
    'Level 1',
    'Level 8',
    'FORUM',
    'EXTENSIONS',
    'WIKI / DOC',
    'Installation',
    'step1_host_info',
	'Administration',
	'Redirection...',
	'Menu',
	'%d photo',
	'%d photos',
	'Configuration',
	'Instructions',
	'Permissions',
	'Local',
	'[Simulation]',
	'Section',
	'Correction',
	'Support',
	'Extensions',
	'Documentation',
	'Photos',
	'photo',
	'pixels',
	'Piwigo Uploader',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	'email',
	'Albums',
	'Album',
	'Menu Management',
	'Action',
    ),
	
  'he_IL' => array(
	'localhost, sql.multimania.com, toto.freesurf.fr',
	),
	
  'hr_HR' => array(
	'%d Kb',
	'Filter',
	'Tag',
	'Webmaster',
	'IP: %s',
	'%d tag',
	'user_status_webmaster',
	'IP',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	),
	
  'hu_HU' => array(
	'Album',
	'Album: %s',
	),

  'it_IT' => array(
	'Album',
    'Album: %s',
    'Browser: %s',
	'Database',
	'Directory',
	'Download',
	'Downloads',
	'email',
	'Email',
	'Email: %s',
	'File',
	'Home',
	'high',
	'Host',
	'IP',
	'IP: %s',
	'Links',
	'Logout',
	'Menu',
	'N/A',
	'No',
	'Password',
	'Permalink',
	'Permalinks',
	'pixels',
	'Piwigo Uploader',
	'Plugin',
	'Plugins',
	'Tag',
	'Tags',
	'%d tag',
	'%d tags',
	'Tools',
	'user_status_webmaster',
	'Webmaster',
	),
	
  'ja_JP' => array(
 	'About',
	'Since',
	'Powered by',
 	'IP: %s',
	'IP',
	'Sent by',
	'%d Kb',
	'',
	),
	
  'lv_LV' => array(
 	'%d Kb',
	'N/A',
	'IP: %s',
	'IP',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	'',
	'',
	'',
	),

  'nl_NL' => array(
 	'%d Kb',
	'Filter',
	'Help',
	'Links',
	'RSS feed',
	'Reset',
	'Tag',
	'Tags',
	'Week %d',
	'download',
	'Powered by',
	'Auto login',
	'Contact',
	'SQL queries in',
	'Menu',
	'IP: %s',
	'Browser: %s',
	'Email: %s',
	'Piwigo Help',
	'%d tag',
	'%d tags',
	'Batch management',
	'Database',
	'Permalink',
	'Permalinks',
	'Plugins',
	'Representant',
	'Site manager',
	'Status',
	'email',
	'Parameter',
	'Parameters',
	'Remote site',
	'test',
	'Remote',
	'unit mode',
	'Upload',
	'IP',
	'Level 8',
	'Demo',
	'Hits',
	'Downloads',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	'Upgrade',
	'SQL queries',
 	'letters',
	'This author removed the comment with id %d',
	'Database type',
	'Sorry!',
	'Hope to see you back soon.',
	'Hit',
	'pixels',
	'Download',
	'Piwigo Uploader',
	'Download,',
	),
	
  'no_NO' => array(
 	'IP: %s',
	'Browser: %s',
	'Email: %s',
	'Admin: %s',
	'Pause of slideshow',
	'Album',
	'Filter',
	'N/A',
	'Webmaster',
	'%d Kb',
	'representative',
	'slideshow',
	'Album: %s',
	'Album results for',
	'%d tag',
	'Database',
	'Permalink',
	'Representant',
	'Representative',
	'Status',
	'Main',
	'email',
	'Parameter',
	'Send',
	'test',
	'status',
	'user_status_admin',
	'user_status_webmaster',
	'IP',
	'Element',
	'Tags',
	'Element type',
	'Database type',
	'Host',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	),
	
  'pl_PL' => array(
 	'%d Kb',
	'RSS feed',
	'Webmaster',
	'IP: %s',
	'Tag',
	'Powered by',
	'Email: %s',
	'Admin: %s',
	'%d tag',
	'Status',
	'test',
	'status',
	'user_status_admin',
	'user_status_webmaster',
	'localhost, sql.multimania.com, toto.freesurf.fr',	
	'IP',		
	'Menu',			
	'Album',
	),

  'pt_BR' => array(
	'localhost, sql.multimania.com, toto.freesurf.fr',
	),
	
  'pt_PT' => array(
	'%d Kb',
	'Links',
	'Webmaster',
	'Powered by',
	'IP: %s',
	'Email: %s',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	'Permalinks',
	'Plugins',
	'Local',
	'user_status_webmaster',
	'IP',
	'Downloads',
	'Download',
	'Download,',	
	),
	
  'ro_RO' => array(
	'%d Kb',
	'N/A',
	'RSS feed',
	'Webmaster',
	'Calendar',
	'Contact',
	),

  'ru_RU' => array(
	'IP',
	'IP: %s',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	'',
	),

  'sl_SL' => array(
	'%d Kb',
	'Filter',
	'N/A',
	'caddie',
	'IP: %s',
	'show tag cloud',
	'cloud',
	),
	
  'sk_SK' => array(
	'%d Kb',
	'Album',
	'Filter',
	'Webmaster',
	'IP: %s',
	'Album: %s',
	'test',
	'user_status_webmaster',
	'IP',
	),
	
  'sr_RS' => array(
 	'%d Kb',
	'Filter',
	'Webmaster',
	'IP: %s',
	'user_status_admin',
	'user_status_webmaster',
	'IP',
	'Element',
	'Host',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	),
	
  'sv_SE' => array(
 	'%d association',
	'Plugins',
	'Position',
	'Representant',
	'Status',
	'Version',
	'High definition',
	'test',
	'status',
	'Piwigo administration',
	'GD version',
	'user_status_webmaster',
	'IP',
	'Element',
	'Piwigo Administration',
	'Piwigo version',
	'IP: %s',
	'Admin: %s',
	'Filter',
	'Administration',
	'%d Kb',
	'Installation',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	'Album: %s',
	'Album',
	'Informations',
	),
	
  'tr_TR' => array(
 	'%d hit',
	'N/A',
	'Webmaster',
	'IP: %s',
	'Host',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	),
	
  'vi_VN' => array(
	'%d Kb',
	'Caddie',
	'Form',
	'Plugins',
	'user_status_webmaster',
	'Templates',
	'pixels',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	),
	
  'zh_CN' => array(
	'IP',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	'%d Kb',
	),

  'zh_TW' => array(
	'IP',
	'localhost, sql.multimania.com, toto.freesurf.fr',
	),	
  );
?>
